@@ -701,7 +701,11 @@ my $CL_URGENCY = '';
 
 if (!$opt_create || ($opt_create && $opt_news)) {
     my $file = $opt_create ? 'debian/changelog' : $changelog_path;
-    $changelog = changelog_parse(file => $file);
+    $changelog = changelog_parse(
+        filename => $file,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+        file => $file,
+    );
 
     # Now we've read the changelog, set some variables and then
     # let's check the directory name is sensible
@@ -733,7 +737,11 @@ if (!$opt_create || ($opt_create && $opt_news)) {
     if ($opt_news) {
         my $found_version = 0;
         my $found_urgency = 0;
-        my $clog          = changelog_parse(file => $real_changelog_path);
+        my $clog          = changelog_parse(
+            filename => $real_changelog_path,
+            # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+            file => $real_changelog_path,
+        );
         $VERSION = $clog->{Version};
         $VERSION =~ s/~$//;
 
@@ -1306,6 +1314,10 @@ if ((
                 and $vendor eq 'Ubuntu'
                 and not $start =~ /build/
                 and not $start =~ /ubuntu/) {
+                if ($end =~ /ubuntu$/) {
+                    # Separate ubuntu-native rebuild to ubuntu.build1
+                    $end .= ".";
+                }
                 $end .= "build1";
             } elsif ($opt_R
                 and $vendor eq 'Tanglu'
@@ -1337,12 +1349,29 @@ if ((
                     and $start !~ /(ubuntu|~ppa)(\d+\.)*$/
                     and not $opt_U) {
 
-                    if ($start =~ /build/) {
-                        # Drop buildX suffix in favor of ubuntu1
-                        $start =~ s/build//;
-                        $end = "";
+                    if ($start =~ /(.*?)(ubuntu)?(\.?build)/) {
+                       # Drop 'buildX' suffix in favor of 'ubuntu' or 'ubuntu1'
+                        $start = $1;
+                        $end   = $2 || '';
+                    }
+
+                    # ubuntu-native package with form "${version}ubuntu"
+                    if (    $end =~ '^ubuntu'
+                        and $start =~ /(.*?)(\d+)$/i) {
+                        if ($VERSION =~ /-/) {
+                           # version contains -, so not a not a native package.
+                            fatal
+"Version $(VERSION) suffix indicates native Ubuntu package, "
+                              . "but the included '-' suggests the contrary. "
+                              . "Perhaps you're missing a digit behind 'ubuntu'?";
+                        }
+                        my $versionhead = $1;
+                        my $versiontail = $2;
+                        $versiontail++;
+                        $start = "$versionhead$versiontail";
+                    } else {
+                        $end .= "ubuntu1";
                     }
-                    $end .= "ubuntu1";
                 } elsif (($opt_i or $opt_s)
                     and $vendor eq 'Tanglu'
                     and $start !~ /(tanglu)(\d+\.)*$/
