@@ -159,6 +159,7 @@ use Dpkg::Control;
 use Dpkg::Version;
 use Dpkg::IPC;
 use Dpkg::Deps;
+use Dpkg::Path qw(find_command);
 use FileHandle;
 use Text::ParseWords;
 
@@ -261,8 +262,7 @@ if (!@ARGV) {
 
 usage(1) unless @ARGV;
 
-system("command -v equivs-build >/dev/null 2>&1");
-if ($?) {
+if (!find_command('equivs-build')) {
     die "$progname: You must have equivs installed to use this program.\n";
 }
 
@@ -358,7 +358,10 @@ while ($control = shift) {
             if (-f $changelog) {
                 require Dpkg::Changelog::Parse;
                 my $log = Dpkg::Changelog::Parse::changelog_parse(
-                    file => $changelog);
+                    filename => $changelog,
+                    # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+                    file => $changelog,
+                );
                 if ($ctrl->{$name} eq $log->{$name}) {
                     $ctrl->{Version} = $log->{Version};
                     push(@versions, $log->{Version});
